title: Build and run Musubi

Subsequently is a short explanation on how to use Musubi:

- Checkout: 
    - <tt>hg clone https://geb.inf.tu-dresden.de/hg/musubi</tt>

  then you have the repository with sub-repos aotus and treelm in the folder
  <tt>musubi</tt>.
- Note: You need MPI in order to compile the code. 

- Set environment variables
    - <tt>export CC=mpicc</tt>
    - <tt>export FC=mpif90</tt>
- Configure
    - <tt>./waf configure</tt>
- Build 
    - <tt>./waf build</tt>
- Change settings in <tt>musubi.lua</tt>
- Run 
    - <tt>./build/musubi</tt>

You will get .vtk files, if you have activated the output in
<tt>musubi.lua</tt>.  The current test case is a Gaussian Pulse with a wall in
order to test the correct behavior of the bounce back boundaries.

# Configuration options

There are several configuration options available to influence the build.
You can obtain a list of those with <tt>./waf --help</tt>.

It is possible to choose between the "PULL" (default) and "PUSH" streaming
approach via the <tt>--stream=PULL</tt> or <tt>--stream=PUSH</tt> option.

# Build variants

Aside from the default <tt>build</tt>, there is also a <tt>debug</tt> target
which creates an executable with debugging information.
Other variants, for example for performance profiling can be found in the output
of <tt>./waf --help</tt>

# Coco preprocessing

Musubi utilizes the CoCo preprocessor to modify code at compile time.
Its behavior can be modified by changing the <tt>default.coco</tt> file, and
by setting the <tt>COCOFLAGS</tt> environment variable.

# Limiting what is build

It is possible to restrict to build to individual targets with the
<tt>--targets</tt> option.
For example to only build the <tt>musubi</tt> and <tt>mus_harvesting</tt>
executables, add the option <tt>--targets=musubi,mus_harvesting</tt> to the waf
command.

# Generate a geometry 

A different geometry can be generated with the tree-based Mesh generator Seeder.

## Build and run Seeder

- Checkout: <tt>hg clone https://geb.inf.tu-dresden.de/hg/seeder</tt>
  then you have the repository with sub-repos aotus and treelm in the folder
  <tt>seeder</tt>.
- Note: You need MPI in order to compile the code.

Set environment variables
<tt>export CC=mpicc</tt>
<tt>export FC=mpif90</tt>

- Configure <tt>./waf configure</tt>
- Build <tt>./waf build</tt>
- Generate mesh folder in current folder: <tt>mkdir ./mesh</tt>
- Change settings in <tt>input/config.lua</tt>. Specify the STL file(s) and set
  the min and max tree levels.
  Note: In the current version, Musubi only supports uniform grids, which can be
  generated by setting <tt>maxrefine = minrefine</tt>.
- Run <tt>./build/seeder input/config.lua</tt>
- Generated mesh is in the <tt>mesh/</tt> folder
- Copy all files from <tt>mesh</tt> to the musubi mesh folder
  <tt>../musubi/mesh</tt>

You will receive a VTK file, in order to check the fluid domain. The fluid is
identified by placing the seed in the correct position in seeder.f90, which
will be changed later. A good start is in the first position, just make sure
that it is part of the continuous fluid domain.


The parallel version has not been tackled yet but has a high priority on our
task-list.
The next step will be parallel functionality and inlet/outlet boundaries.

Please make sure to check out musubi and start a few runs.
Please also report any bugs here in the tickets.

@note After updating a new version of Musubi you better do
<tt>./waf configure build</tt>.
Sometimes you need to clean the coco macro files.
Then you do <tt>./waf clean build</tt>.
To remove the source and the configuration files you type
<tt>./waf distclean configure build</tt>.
And if you want to remove the coco executables itself you will type
<tt>./waf cleanall configure build</tt>.
